@@ -244,20 +244,24 @@ Clear?  Good.
   use Apache2::ASP::Config;
   my $config = Apache2::ASP::Config->new();
   
-  print $config->www_root;                        # /usr/local/dstack/htdocs
+  print $config->www_root;                        # /var/www/html
   
   print $config->application_name;                # DefaultApp
   
-  print $config->handler_root;                    # /usr/local/dstack/handlers
+  print $config->handler_root;                    # /var/www/html/handlers
   
-  print $config->page_cache_root;                 # /usr/local/dstack/PAGE_CACHE
+  print $config->page_cache_root;                 # /var/www/html/PAGE_CACHE
   
-  print $config->media_manager_upload_root;       # /usr/local/dstack/MEDIA
+  print $config->media_manager_upload_root;       # /var/www/html/MEDIA
   
   print $config->application_state->manager;      # Apache2::ASP::ApplicationStateManager::SQLite
   
   print $config->application_state->dsn;          # DBI:SQLite:dbname=/tmp/apache2_asp_state
   
+  print $config->application_state->username;     # "username"
+  
+  print $config->application_state->password;     # "password"
+  
   print $config->session_state->manager;          # Apache2::ASP::SessionStateManager::SQLite
   
   print $config->session_state->cookie_domain;    # .yoursite.com
@@ -266,14 +270,29 @@ Clear?  Good.
   
   print $config->session_state->dsn;              # DBI:SQLite:dbname=/tmp/apache2_asp_state
   
+  print $config->session_state->username;         # "username"
+  
+  print $config->session_state->password;         # "password"
+  
   print $config->session_state->session_timeout;  # 30 (means 30 minutes)
+  
+  print $config->settings->lib;                   # /usr/local
+  
+  print $config->settings->dsn;                   # DBI:mysql:dbname:hostname
+  
+  print $config->settings->username;              # "username"
+  
+  print $config->settings->password;              # "password"
 
 =head1 DESCRIPTION
 
 Each web application gets its own configuration.  For more information about the config xml format,
 see L<Apache2::ASP::GlobalConfig>.
 
-=head1 METHODS
+For information on setting up the configuration, please refer to L<Apache2::ASP::Manual::Intro> 
+and L<Apache2::ASP::Manual::ConfigXML>.
+
+=head1 PUBLIC METHODS
 
 =head2 new( )
 
@@ -283,6 +302,86 @@ Returns a new C<Apache2::ASP::Config> object.
 
 Used for testing, but it could (possibly) be useful some other way.  Validates the config.  Dies if the config contains errors.
 
+=head1 PUBLIC PROPERTIES
+
+=head2 $config->www_root
+
+Returns 
+
+=head2 $config->application_name
+
+See synopsis.
+
+=head2 $config->handler_root
+
+See synopsis.
+
+=head2 $config->page_cache_root
+
+See synopsis.
+
+=head2 $config->media_manager_upload_root
+
+See synopsis.
+
+=head2 $config->application_state->manager
+
+See synopsis.
+
+=head2 $config->application_state->dsn
+
+See synopsis.
+
+=head2 $config->application_state->username
+
+See synopsis.
+
+=head2 $config->application_state->password
+
+See synopsis.
+
+=head2 $config->session_state->manager
+
+See synopsis.
+
+=head2 $config->session_state->cookie_domain
+
+See synopsis.
+
+=head2 $config->session_state->cookie_name
+
+See synopsis.
+
+=head2 $config->session_state->dsn
+
+See synopsis.
+
+=head2 $config->session_state->username
+
+See synopsis.
+
+=head2 $config->session_state->password
+
+See synopsis.
+
+=head2 $config->settings->lib
+
+The path to your Application-specific Perl modules, B<not> your Handlers.
+
+Generally these are L<Class::DBI> or L<DBIx::Class> modules (or whatever you prefer to use).
+
+=head2 $config->settings->dsn
+
+The connectionstring your application uses.
+
+=head2 $config->settings->username
+
+The username for your application's connectionstring.
+
+=head2 $config->settings->password
+
+The password for your application's connectionstring.
+
 =head1 BUGS
 
 It's possible that some bugs have found their way into this release.
